#!/usr/bin/env python

from distutils.core import setup

setup(name='peyote',
      version='0.2',
      description='Peyote is a remote logging service for Django.',
      author='Matt Caldwell',
      author_email='matt.caldwell@gmail.com',
      url='https://github.com/mattcaldwell/peyote',
      packages=['peyote']
)
